---
github_url: https://github.com/echemdb/echemdb-converters/blob/master/echemdbconverters/eclabloader.py
---

# `echemdbconverters.eclabloader`
```{eval-rst}
.. automodule:: echemdbconverters.eclabloader
   :members:
```
